#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Stellaris expansions (species packs):
# - Plantoids
# - Humanoids
# - Lithoids
# - Necroids
# - Aquatics
# - Toxoids
###

script_version=20240313.1

PLAYIT_COMPATIBILITY_LEVEL='2.27'

GAME_ID='stellaris'
GAME_NAME='Stellaris'

EXPANSION_ID_PLANTOID='plantoid'
EXPANSION_NAME_PLANTOID='Plantoids Species Pack'

EXPANSION_ID_HUMANOIDS='humanoids'
EXPANSION_NAME_HUMANOIDS='Humanoids Species Pack'

EXPANSION_ID_LITHOIDS='lithoids'
EXPANSION_NAME_LITHOIDS='Lithoids Species Pack'

EXPANSION_ID_NECROIDS='necroids'
EXPANSION_NAME_NECROIDS='Necroids Species Pack'

EXPANSION_ID_AQUATICS='aquatics'
EXPANSION_NAME_AQUATICS='Aquatics Species Pack'

EXPANSION_ID_TOXOIDS='toxoids'
EXPANSION_NAME_TOXOIDS='Toxoids Species Pack'

# Archives

## Plantoids

ARCHIVE_BASE_PLANTOID_51_NAME='stellaris_plantoids_species_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_PLANTOID_51_MD5='8f9da3237c88c7177408e5e076d55ee4'
ARCHIVE_BASE_PLANTOID_51_SIZE='837'
ARCHIVE_BASE_PLANTOID_51_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_PLANTOID_51_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'

ARCHIVE_BASE_PLANTOID_50_NAME='stellaris_plantoids_species_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_PLANTOID_50_MD5='73bc2e3ddcec60a04ed0a3090b32350a'
ARCHIVE_BASE_PLANTOID_50_SIZE='837'
ARCHIVE_BASE_PLANTOID_50_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_PLANTOID_49_NAME='stellaris_plantoids_species_pack_3_10_4_70670.sh'
ARCHIVE_BASE_PLANTOID_49_MD5='fc70ea7215520e885c61d072463b9be4'
ARCHIVE_BASE_PLANTOID_49_SIZE='837'
ARCHIVE_BASE_PLANTOID_49_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_PLANTOID_43_NAME='stellaris_plantoids_species_pack_3_9_3_68314.sh'
ARCHIVE_BASE_PLANTOID_43_MD5='f38e8c826f876f52cea68b69f85ca079'
ARCHIVE_BASE_PLANTOID_43_SIZE='1156'
ARCHIVE_BASE_PLANTOID_43_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_PLANTOID_40_NAME='stellaris_plantoids_species_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_PLANTOID_40_MD5='c64fed3a260b17bdb07e439dc20304c7'
ARCHIVE_BASE_PLANTOID_40_SIZE='1200'
ARCHIVE_BASE_PLANTOID_40_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_PLANTOID_39_NAME='stellaris_plantoids_species_pack_3_8_3_1_64953.sh'
ARCHIVE_BASE_PLANTOID_39_MD5='7b0cec949d962b027bc7bd108d79eeaf'
ARCHIVE_BASE_PLANTOID_39_SIZE='1200'
ARCHIVE_BASE_PLANTOID_39_VERSION='3.8.3.1-gog64953'

ARCHIVE_BASE_PLANTOID_36_NAME='stellaris_plantoids_species_pack_3_7_4_63489.sh'
ARCHIVE_BASE_PLANTOID_36_MD5='5a2a9101e09cddc83e29c802b33639ed'
ARCHIVE_BASE_PLANTOID_36_SIZE='1200'
ARCHIVE_BASE_PLANTOID_36_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_PLANTOID_33_NAME='stellaris_plantoids_species_pack_3_6_1_60754.sh'
ARCHIVE_BASE_PLANTOID_33_MD5='298bdd7c0f717f90c2045d0c9a68c1c9'
ARCHIVE_BASE_PLANTOID_33_SIZE='1200'
ARCHIVE_BASE_PLANTOID_33_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_PLANTOID_31_NAME='stellaris_plantoids_species_pack_3_5_3_59410.sh'
ARCHIVE_BASE_PLANTOID_31_MD5='fabc6b9d5580dac6a456da962a765709'
ARCHIVE_BASE_PLANTOID_31_SIZE='1200'
ARCHIVE_BASE_PLANTOID_31_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_PLANTOID_29_NAME='stellaris_plantoids_species_pack_3_4_5_56913.sh'
ARCHIVE_BASE_PLANTOID_29_MD5='b2b5023834509b4a5c2a12bb345380a1'
ARCHIVE_BASE_PLANTOID_29_SIZE='1200'
ARCHIVE_BASE_PLANTOID_29_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_PLANTOID_25_NAME='stellaris_plantoids_species_pack_3_3_4_54421.sh'
ARCHIVE_BASE_PLANTOID_25_MD5='b8ea82b781639c7031ea53d4e155c5d1'
ARCHIVE_BASE_PLANTOID_25_SIZE='1200'
ARCHIVE_BASE_PLANTOID_25_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_PLANTOID_21_NAME='stellaris_plantoids_species_pack_3_2_1_1_51520.sh'
ARCHIVE_BASE_PLANTOID_21_MD5='260d8bc704b93f307d31807efbb5568f'
ARCHIVE_BASE_PLANTOID_21_SIZE='1200'
ARCHIVE_BASE_PLANTOID_21_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_PLANTOID_20_NAME='stellaris_plantoids_species_pack_3_1_1_50008.sh'
ARCHIVE_BASE_PLANTOID_20_MD5='fb947af6a98e45645b482a484bd6d42e'
ARCHIVE_BASE_PLANTOID_20_SIZE='1200'
ARCHIVE_BASE_PLANTOID_20_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_PLANTOID_19_NAME='stellaris_plantoids_species_pack_3_0_3_47193.sh'
ARCHIVE_BASE_PLANTOID_19_MD5='d1dc616e45d6d035ed3414687228f95a'
ARCHIVE_BASE_PLANTOID_19_SIZE='1200'
ARCHIVE_BASE_PLANTOID_19_VERSION='3.0.3-gog47193'

## Humanoids

ARCHIVE_BASE_HUMANOIDS_51_NAME='stellaris_humanoids_species_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_HUMANOIDS_51_MD5='ed6ddddac2ff4ed07f970e86a345f91f'
ARCHIVE_BASE_HUMANOIDS_51_SIZE='116312'
ARCHIVE_BASE_HUMANOIDS_51_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_HUMANOIDS_51_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'

ARCHIVE_BASE_HUMANOIDS_50_NAME='stellaris_humanoids_species_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_HUMANOIDS_50_MD5='c021bb7b0d5ae692cbe4839d3a1ab26c'
ARCHIVE_BASE_HUMANOIDS_50_SIZE='116312'
ARCHIVE_BASE_HUMANOIDS_50_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_HUMANOIDS_49_NAME='stellaris_humanoids_species_pack_3_10_4_70670.sh'
ARCHIVE_BASE_HUMANOIDS_49_MD5='515dd7f2ae1c68fe53a589f77b7af19c'
ARCHIVE_BASE_HUMANOIDS_49_SIZE='116312'
ARCHIVE_BASE_HUMANOIDS_49_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_HUMANOIDS_43_NAME='stellaris_humanoids_species_pack_3_9_3_68314.sh'
ARCHIVE_BASE_HUMANOIDS_43_MD5='d970689331dfae6ad559b4dd8d146080'
ARCHIVE_BASE_HUMANOIDS_43_SIZE='116636'
ARCHIVE_BASE_HUMANOIDS_43_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_HUMANOIDS_40_NAME='stellaris_humanoids_species_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_HUMANOIDS_40_MD5='435cdbbe3a8affded29b3b6f9d36125a'
ARCHIVE_BASE_HUMANOIDS_40_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_40_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_HUMANOIDS_36_NAME='stellaris_humanoids_species_pack_3_7_4_63489.sh'
ARCHIVE_BASE_HUMANOIDS_36_MD5='de7661496eba8a9d125b44f3075a71b7'
ARCHIVE_BASE_HUMANOIDS_36_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_36_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_HUMANOIDS_33_NAME='stellaris_humanoids_species_pack_3_6_1_60754.sh'
ARCHIVE_BASE_HUMANOIDS_33_MD5='5124b47dce3c7a7282087e521920fee9'
ARCHIVE_BASE_HUMANOIDS_33_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_33_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_HUMANOIDS_31_NAME='stellaris_humanoids_species_pack_3_5_3_59410.sh'
ARCHIVE_BASE_HUMANOIDS_31_MD5='9f92e8b6853b26bc31da38b5a0991a37'
ARCHIVE_BASE_HUMANOIDS_31_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_31_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_HUMANOIDS_29_NAME='stellaris_humanoids_species_pack_3_4_5_56913.sh'
ARCHIVE_BASE_HUMANOIDS_29_MD5='5fcd93a54b01f93bae743d49bf61860b'
ARCHIVE_BASE_HUMANOIDS_29_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_29_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_HUMANOIDS_25_NAME='stellaris_humanoids_species_pack_3_3_4_54421.sh'
ARCHIVE_BASE_HUMANOIDS_25_MD5='b7ccaa9303516274f7945882bd6a2d2f'
ARCHIVE_BASE_HUMANOIDS_25_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_25_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_HUMANOIDS_21_NAME='stellaris_humanoids_species_pack_3_2_1_1_51520.sh'
ARCHIVE_BASE_HUMANOIDS_21_MD5='d56625b5ce55405530929bea32852f54'
ARCHIVE_BASE_HUMANOIDS_21_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_21_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_HUMANOIDS_20_NAME='stellaris_humanoids_species_pack_3_1_1_50008.sh'
ARCHIVE_BASE_HUMANOIDS_20_MD5='974908ceeb80ade57dfa00c957604d06'
ARCHIVE_BASE_HUMANOIDS_20_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_20_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_HUMANOIDS_19_NAME='stellaris_humanoids_species_pack_3_0_3_47193.sh'
ARCHIVE_BASE_HUMANOIDS_19_MD5='9dc8511383a7c36c54660d6d77d61117'
ARCHIVE_BASE_HUMANOIDS_19_SIZE='120000'
ARCHIVE_BASE_HUMANOIDS_19_VERSION='3.0.3-gog47193'

## Lithoids

ARCHIVE_BASE_LITHOIDS_39_NAME='stellaris_lithoids_species_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_LITHOIDS_39_MD5='6797d75d5adf8f91215134117f480108'
ARCHIVE_BASE_LITHOIDS_39_SIZE='52603'
ARCHIVE_BASE_LITHOIDS_39_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_LITHOIDS_39_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'

ARCHIVE_BASE_LITHOIDS_38_NAME='stellaris_lithoids_species_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_LITHOIDS_38_MD5='9f0f32fd5c35f01d6b414467e19a8865'
ARCHIVE_BASE_LITHOIDS_38_SIZE='52603'
ARCHIVE_BASE_LITHOIDS_38_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_LITHOIDS_37_NAME='stellaris_lithoids_species_pack_3_10_4_70670.sh'
ARCHIVE_BASE_LITHOIDS_37_MD5='96caaa7c76349f34823372cc7f9dc769'
ARCHIVE_BASE_LITHOIDS_37_SIZE='52603'
ARCHIVE_BASE_LITHOIDS_37_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_LITHOIDS_31_NAME='stellaris_lithoids_species_pack_3_9_3_68314.sh'
ARCHIVE_BASE_LITHOIDS_31_MD5='baecdaa00168fe891ff419b71334f313'
ARCHIVE_BASE_LITHOIDS_31_SIZE='52924'
ARCHIVE_BASE_LITHOIDS_31_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_LITHOIDS_28_NAME='stellaris_lithoids_species_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_LITHOIDS_28_MD5='65723d6948a9380c1397b280f9bc20f4'
ARCHIVE_BASE_LITHOIDS_28_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_28_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_LITHOIDS_24_NAME='stellaris_lithoids_species_pack_3_7_4_63489.sh'
ARCHIVE_BASE_LITHOIDS_24_MD5='bfc5632131852032fda229260aa179d6'
ARCHIVE_BASE_LITHOIDS_24_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_24_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_LITHOIDS_21_NAME='stellaris_lithoids_species_pack_3_6_1_60754.sh'
ARCHIVE_BASE_LITHOIDS_21_MD5='0adc3e342f420e26a04b256595eee248'
ARCHIVE_BASE_LITHOIDS_21_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_21_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_LITHOIDS_19_NAME='stellaris_lithoids_species_pack_3_5_3_59410.sh'
ARCHIVE_BASE_LITHOIDS_19_MD5='30bac0aa5302f556fb13511df2e8194b'
ARCHIVE_BASE_LITHOIDS_19_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_19_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_LITHOIDS_17_NAME='stellaris_lithoids_species_pack_3_4_5_56913.sh'
ARCHIVE_BASE_LITHOIDS_17_MD5='54fb17af3ed8b442074c83cf2b818693'
ARCHIVE_BASE_LITHOIDS_17_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_17_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_LITHOIDS_13_NAME='stellaris_lithoids_species_pack_3_3_4_54421.sh'
ARCHIVE_BASE_LITHOIDS_13_MD5='cde1e9ed0deaeff8850242e4157783be'
ARCHIVE_BASE_LITHOIDS_13_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_13_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_LITHOIDS_9_NAME='stellaris_lithoids_species_pack_3_2_1_1_51520.sh'
ARCHIVE_BASE_LITHOIDS_9_MD5='ed5aca5df6d72a84f0572200e1d432fe'
ARCHIVE_BASE_LITHOIDS_9_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_9_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_LITHOIDS_8_NAME='stellaris_lithoids_species_pack_3_1_1_50008.sh'
ARCHIVE_BASE_LITHOIDS_8_MD5='c935a54a2e9ac78d195440d7ca1391f9'
ARCHIVE_BASE_LITHOIDS_8_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_8_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_LITHOIDS_7_NAME='stellaris_lithoids_species_pack_3_0_3_47193.sh'
ARCHIVE_BASE_LITHOIDS_7_MD5='44a8e1008468825af82ec138be388fe9'
ARCHIVE_BASE_LITHOIDS_7_SIZE='53000'
ARCHIVE_BASE_LITHOIDS_7_VERSION='3.0.3-gog47193'

## Necroids

ARCHIVE_BASE_NECROIDS_24_NAME='stellaris_necroids_species_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_NECROIDS_24_MD5='a8da05a632b58a2437fe11317a3a0b71'
ARCHIVE_BASE_NECROIDS_24_SIZE='49209'
ARCHIVE_BASE_NECROIDS_24_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_NECROIDS_24_URL='https://www.gog.com/game/stellaris_necroids_species_pack'

ARCHIVE_BASE_NECROIDS_23_NAME='stellaris_necroids_species_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_NECROIDS_23_MD5='156fa586cf29fad6ef494554ac1b123c'
ARCHIVE_BASE_NECROIDS_23_SIZE='49209'
ARCHIVE_BASE_NECROIDS_23_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_NECROIDS_22_NAME='stellaris_necroids_species_pack_3_10_4_70670.sh'
ARCHIVE_BASE_NECROIDS_22_MD5='5549b1dfec82af2de64537ed751a1920'
ARCHIVE_BASE_NECROIDS_22_SIZE='49209'
ARCHIVE_BASE_NECROIDS_22_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_NECROIDS_16_NAME='stellaris_necroids_species_pack_3_9_3_68314.sh'
ARCHIVE_BASE_NECROIDS_16_MD5='8afbc28fb3af625dd145381e44fe7bde'
ARCHIVE_BASE_NECROIDS_16_SIZE='49524'
ARCHIVE_BASE_NECROIDS_16_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_NECROIDS_13_NAME='stellaris_necroids_species_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_NECROIDS_13_MD5='2614b147a120b97e0d5e4f0a24719f82'
ARCHIVE_BASE_NECROIDS_13_SIZE='50000'
ARCHIVE_BASE_NECROIDS_13_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_NECROIDS_9_NAME='stellaris_necroids_species_pack_3_7_4_63489.sh'
ARCHIVE_BASE_NECROIDS_9_MD5='631269beefca458e901a727af53e09d0'
ARCHIVE_BASE_NECROIDS_9_SIZE='50000'
ARCHIVE_BASE_NECROIDS_9_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_NECROIDS_6_NAME='stellaris_necroids_species_pack_3_6_1_60754.sh'
ARCHIVE_BASE_NECROIDS_6_MD5='13605c18c7d483b3c8abeff2d60c65f7'
ARCHIVE_BASE_NECROIDS_6_SIZE='50000'
ARCHIVE_BASE_NECROIDS_6_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_NECROIDS_4_NAME='stellaris_necroids_species_pack_3_5_3_59410.sh'
ARCHIVE_BASE_NECROIDS_4_MD5='23faec896d52d6f2773e19838f365113'
ARCHIVE_BASE_NECROIDS_4_SIZE='50000'
ARCHIVE_BASE_NECROIDS_4_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_NECROIDS_2_NAME='stellaris_necroids_species_pack_3_4_5_56913.sh'
ARCHIVE_BASE_NECROIDS_2_MD5='e64ecf03e49671cedf3e164709a5837a'
ARCHIVE_BASE_NECROIDS_2_SIZE='50000'
ARCHIVE_BASE_NECROIDS_2_VERSION='3.4.5-gog56913'

## Aquatics

ARCHIVE_BASE_AQUATICS_22_NAME='stellaris_aquatics_species_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_AQUATICS_22_MD5='9742e44f595eb51f4c1812844aea7d9b'
ARCHIVE_BASE_AQUATICS_22_SIZE='120876'
ARCHIVE_BASE_AQUATICS_22_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_AQUATICS_22_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'

ARCHIVE_BASE_AQUATICS_21_NAME='stellaris_aquatics_species_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_AQUATICS_21_MD5='19a9731693cab683354100925254e466'
ARCHIVE_BASE_AQUATICS_21_SIZE='120876'
ARCHIVE_BASE_AQUATICS_21_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_AQUATICS_20_NAME='stellaris_aquatics_species_pack_3_10_4_70670.sh'
ARCHIVE_BASE_AQUATICS_20_MD5='335d95744fa5467cad87e276fb8d6997'
ARCHIVE_BASE_AQUATICS_20_SIZE='120876'
ARCHIVE_BASE_AQUATICS_20_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_AQUATICS_14_NAME='stellaris_aquatics_species_pack_3_9_3_68314.sh'
ARCHIVE_BASE_AQUATICS_14_MD5='39294019e3f068916fea06f68e35b1ee'
ARCHIVE_BASE_AQUATICS_14_SIZE='121448'
ARCHIVE_BASE_AQUATICS_14_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_AQUATICS_11_NAME='stellaris_aquatics_species_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_AQUATICS_11_MD5='34a45daa4a4d1bf204dc9798917692b5'
ARCHIVE_BASE_AQUATICS_11_SIZE='130000'
ARCHIVE_BASE_AQUATICS_11_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_AQUATICS_7_NAME='stellaris_aquatics_species_pack_3_7_4_63489.sh'
ARCHIVE_BASE_AQUATICS_7_MD5='f825b3f150a7d936b04b3f5bd35d9f5b'
ARCHIVE_BASE_AQUATICS_7_SIZE='130000'
ARCHIVE_BASE_AQUATICS_7_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_AQUATICS_4_NAME='stellaris_aquatics_species_pack_3_6_1_60754.sh'
ARCHIVE_BASE_AQUATICS_4_MD5='5cfdb2861b8c3de9c83798799b477ad6'
ARCHIVE_BASE_AQUATICS_4_SIZE='130000'
ARCHIVE_BASE_AQUATICS_4_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_AQUATICS_2_NAME='stellaris_aquatics_species_pack_3_5_3_59410.sh'
ARCHIVE_BASE_AQUATICS_2_MD5='7e3210b2d64b851907a97ed3455ad035'
ARCHIVE_BASE_AQUATICS_2_SIZE='130000'
ARCHIVE_BASE_AQUATICS_2_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_AQUATICS_0_NAME='stellaris_aquatics_species_pack_3_4_5_56913.sh'
ARCHIVE_BASE_AQUATICS_0_MD5='0d6fe86d3ec24b114742a333b8de4a3b'
ARCHIVE_BASE_AQUATICS_0_SIZE='130000'
ARCHIVE_BASE_AQUATICS_0_VERSION='3.4.5-gog56913'

## Toxoids

ARCHIVE_BASE_TOXOIDS_15_NAME='stellaris_toxoids_species_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_TOXOIDS_15_MD5='e470323a49473a2391adea501d21959a'
ARCHIVE_BASE_TOXOIDS_15_SIZE='41495'
ARCHIVE_BASE_TOXOIDS_15_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_TOXOIDS_15_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'

ARCHIVE_BASE_TOXOIDS_14_NAME='stellaris_toxoids_species_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_TOXOIDS_14_MD5='358f59d88b28f0b9d9c123280a729d8f'
ARCHIVE_BASE_TOXOIDS_14_SIZE='41495'
ARCHIVE_BASE_TOXOIDS_14_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_TOXOIDS_13_NAME='stellaris_toxoids_species_pack_3_10_4_70670.sh'
ARCHIVE_BASE_TOXOIDS_13_MD5='ee41aba19af2f2f91bbe3c156bf614f5'
ARCHIVE_BASE_TOXOIDS_13_SIZE='41495'
ARCHIVE_BASE_TOXOIDS_13_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_TOXOIDS_7_NAME='stellaris_toxoids_species_pack_3_9_3_68314.sh'
ARCHIVE_BASE_TOXOIDS_7_MD5='69ee5d18ffe310c64ee61934ec64aa1f'
ARCHIVE_BASE_TOXOIDS_7_SIZE='41812'
ARCHIVE_BASE_TOXOIDS_7_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_TOXOIDS_4_NAME='stellaris_toxoids_species_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_TOXOIDS_4_MD5='90926bd74621bf180a074d4721b594f9'
ARCHIVE_BASE_TOXOIDS_4_SIZE='42000'
ARCHIVE_BASE_TOXOIDS_4_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_TOXOIDS_0_NAME='stellaris_toxoids_species_pack_3_7_4_63489.sh'
ARCHIVE_BASE_TOXOIDS_0_MD5='e6af2b93063b67bc78d6a44c70caee1c'
ARCHIVE_BASE_TOXOIDS_0_SIZE='42000'
ARCHIVE_BASE_TOXOIDS_0_VERSION='3.7.4-gog63489'


CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_MAIN_FILES='
dlc'

PKG_MAIN_DEPS="$GAME_ID"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_default

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
