#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Stellaris expansions (story packs):
# - Leviathans
# - Synthetic Dawn
# - Distant Stars
# - Ancient Relics
# - First Contact
###

script_version=20240313.1

PLAYIT_COMPATIBILITY_LEVEL='2.27'

GAME_ID='stellaris'
GAME_NAME='Stellaris'

EXPANSION_ID_LEVIATHANS='leviathans'
EXPANSION_NAME_LEVIATHANS='Leviathans Story Pack'

EXPANSION_ID_SYNTHETICDAWN='synthetic-dawn'
EXPANSION_NAME_SYNTHETICDAWN='Synthetic Dawn Story Pack'

EXPANSION_ID_DISTANTSTARS='distant-stars'
EXPANSION_NAME_DISTANTSTARS='Distant Stars Story Pack'

EXPANSION_ID_ANCIENTRELICS='ancient-relics'
EXPANSION_NAME_ANCIENTRELICS='Ancient Relics Story Pack'

EXPANSION_ID_FIRSTCONTACT='first-contact'
EXPANSION_NAME_FIRSTCONTACT='First Contact Story Pack'

# Archives

## Leviathans

ARCHIVE_BASE_LEVIATHANS_51_NAME='stellaris_leviathans_story_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_LEVIATHANS_51_MD5='cfd4f3ab063b0a5f4f8a573b98ab2ca8'
ARCHIVE_BASE_LEVIATHANS_51_SIZE='58426'
ARCHIVE_BASE_LEVIATHANS_51_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_LEVIATHANS_51_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'

ARCHIVE_BASE_LEVIATHANS_50_NAME='stellaris_leviathans_story_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_LEVIATHANS_50_MD5='7feb51d1a76ba3c8ef39050923a6e7b5'
ARCHIVE_BASE_LEVIATHANS_50_SIZE='58426'
ARCHIVE_BASE_LEVIATHANS_50_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_LEVIATHANS_49_NAME='stellaris_leviathans_story_pack_3_10_4_70670.sh'
ARCHIVE_BASE_LEVIATHANS_49_MD5='ca7bd55fd1121dff315cf4bdc748ce5c'
ARCHIVE_BASE_LEVIATHANS_49_SIZE='58426'
ARCHIVE_BASE_LEVIATHANS_49_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_LEVIATHANS_43_NAME='stellaris_leviathans_story_pack_3_9_3_68314.sh'
ARCHIVE_BASE_LEVIATHANS_43_MD5='12ed6b4e72c61d7d5a2223acfe3dec45'
ARCHIVE_BASE_LEVIATHANS_43_SIZE='58744'
ARCHIVE_BASE_LEVIATHANS_43_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_LEVIATHANS_40_NAME='stellaris_leviathans_story_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_LEVIATHANS_40_MD5='575490fe9da72c0211e65e42e2667544'
ARCHIVE_BASE_LEVIATHANS_40_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_40_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_LEVIATHANS_36_NAME='stellaris_leviathans_story_pack_3_7_4_63489.sh'
ARCHIVE_BASE_LEVIATHANS_36_MD5='e9bc3c4a49159663d905892a0f7f5a75'
ARCHIVE_BASE_LEVIATHANS_36_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_36_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_LEVIATHANS_33_NAME='stellaris_leviathans_story_pack_3_6_1_60754.sh'
ARCHIVE_BASE_LEVIATHANS_33_MD5='9ef91ba3bb1633cf4cb907f5de892817'
ARCHIVE_BASE_LEVIATHANS_33_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_33_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_LEVIATHANS_31_NAME='stellaris_leviathans_story_pack_3_5_3_59410.sh'
ARCHIVE_BASE_LEVIATHANS_31_MD5='46f80e45435155c5c94aa1f3bbabf797'
ARCHIVE_BASE_LEVIATHANS_31_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_31_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_LEVIATHANS_29_NAME='stellaris_leviathans_story_pack_3_4_5_56913.sh'
ARCHIVE_BASE_LEVIATHANS_29_MD5='514ca47c97e6edf951697ba361df53bd'
ARCHIVE_BASE_LEVIATHANS_29_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_29_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_LEVIATHANS_25_NAME='stellaris_leviathans_story_pack_3_3_4_54421.sh'
ARCHIVE_BASE_LEVIATHANS_25_MD5='367a1abfe37c32461302cf84c9bdd551'
ARCHIVE_BASE_LEVIATHANS_25_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_25_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_LEVIATHANS_21_NAME='stellaris_leviathans_story_pack_3_2_1_1_51520.sh'
ARCHIVE_BASE_LEVIATHANS_21_MD5='33a7db46efae680eb6718ccd6c386e53'
ARCHIVE_BASE_LEVIATHANS_21_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_21_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_LEVIATHANS_20_NAME='stellaris_leviathans_story_pack_3_1_1_50008.sh'
ARCHIVE_BASE_LEVIATHANS_20_MD5='162521d883f491fcb4e397b9a60c46fd'
ARCHIVE_BASE_LEVIATHANS_20_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_20_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_LEVIATHANS_19_NAME='stellaris_leviathans_story_pack_3_0_3_47193.sh'
ARCHIVE_BASE_LEVIATHANS_19_MD5='70f70d4656a3b3069bec4b138b1c27d5'
ARCHIVE_BASE_LEVIATHANS_19_SIZE='59000'
ARCHIVE_BASE_LEVIATHANS_19_VERSION='3.0.3-gog47193'

## Synthetic Dawn

ARCHIVE_BASE_SYNTHETICDAWN_50_NAME='stellaris_synthetic_dawn_story_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_SYNTHETICDAWN_50_MD5='345e5da3011943fc9efc19c25c4df9ad'
ARCHIVE_BASE_SYNTHETICDAWN_50_SIZE='48244'
ARCHIVE_BASE_SYNTHETICDAWN_50_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_SYNTHETICDAWN_50_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'

ARCHIVE_BASE_SYNTHETICDAWN_49_NAME='stellaris_synthetic_dawn_story_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_SYNTHETICDAWN_49_MD5='036f07141784a0b289b778e1d4b49f63'
ARCHIVE_BASE_SYNTHETICDAWN_49_SIZE='48244'
ARCHIVE_BASE_SYNTHETICDAWN_49_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_SYNTHETICDAWN_48_NAME='stellaris_synthetic_dawn_story_pack_3_10_4_70670.sh'
ARCHIVE_BASE_SYNTHETICDAWN_48_MD5='4b16f920acc6b2257386f020192aafce'
ARCHIVE_BASE_SYNTHETICDAWN_48_SIZE='48244'
ARCHIVE_BASE_SYNTHETICDAWN_48_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_SYNTHETICDAWN_42_NAME='stellaris_synthetic_dawn_story_pack_3_9_3_68314.sh'
ARCHIVE_BASE_SYNTHETICDAWN_42_MD5='b2f35b4c887634e98fbce5e737dd78d1'
ARCHIVE_BASE_SYNTHETICDAWN_42_SIZE='48564'
ARCHIVE_BASE_SYNTHETICDAWN_42_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_SYNTHETICDAWN_39_NAME='stellaris_synthetic_dawn_story_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_SYNTHETICDAWN_39_MD5='8752ebda6f3ff2a6f1f3ae38ee50e3e8'
ARCHIVE_BASE_SYNTHETICDAWN_39_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_39_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_SYNTHETICDAWN_35_NAME='stellaris_synthetic_dawn_story_pack_3_7_4_63489.sh'
ARCHIVE_BASE_SYNTHETICDAWN_35_MD5='09458636f871c76f7e22cc468a7a9f41'
ARCHIVE_BASE_SYNTHETICDAWN_35_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_35_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_SYNTHETICDAWN_32_NAME='stellaris_synthetic_dawn_story_pack_3_6_1_60754.sh'
ARCHIVE_BASE_SYNTHETICDAWN_32_MD5='1e203e5c19fe5c63400cf566fea62164'
ARCHIVE_BASE_SYNTHETICDAWN_32_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_32_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_SYNTHETICDAWN_30_NAME='stellaris_synthetic_dawn_story_pack_3_5_3_59410.sh'
ARCHIVE_BASE_SYNTHETICDAWN_30_MD5='8f6b7a85ca65572e15f61d724ea99317'
ARCHIVE_BASE_SYNTHETICDAWN_30_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_30_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_SYNTHETICDAWN_28_NAME='stellaris_synthetic_dawn_story_pack_3_4_5_56913.sh'
ARCHIVE_BASE_SYNTHETICDAWN_28_MD5='cbcd2a2c6d1b088b634842b9d4abb941'
ARCHIVE_BASE_SYNTHETICDAWN_28_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_28_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_SYNTHETICDAWN_24_NAME='stellaris_synthetic_dawn_story_pack_3_3_4_54421.sh'
ARCHIVE_BASE_SYNTHETICDAWN_24_MD5='b89665cf745898060051099d606a889d'
ARCHIVE_BASE_SYNTHETICDAWN_24_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_24_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_SYNTHETICDAWN_20_NAME='stellaris_synthetic_dawn_story_pack_3_2_1_1_51520.sh'
ARCHIVE_BASE_SYNTHETICDAWN_20_MD5='9b00445bf6b381832f6de06e2f5b7827'
ARCHIVE_BASE_SYNTHETICDAWN_20_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_20_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_SYNTHETICDAWN_19_NAME='stellaris_synthetic_dawn_story_pack_3_1_1_50008.sh'
ARCHIVE_BASE_SYNTHETICDAWN_19_MD5='69ba65596bc537841adc7c70ff0778a9'
ARCHIVE_BASE_SYNTHETICDAWN_19_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_19_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_SYNTHETICDAWN_18_NAME='stellaris_synthetic_dawn_story_pack_3_0_3_47193.sh'
ARCHIVE_BASE_SYNTHETICDAWN_18_MD5='b4231ca3b95b4bdb9e9a2e33c747d8c5'
ARCHIVE_BASE_SYNTHETICDAWN_18_SIZE='49000'
ARCHIVE_BASE_SYNTHETICDAWN_18_VERSION='3.0.3-gog47193'

## Distant Stars

ARCHIVE_BASE_DISTANTSTARS_50_NAME='stellaris_distant_stars_story_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_DISTANTSTARS_50_MD5='3ff9d14e4d29428b22ec41114ba072fb'
ARCHIVE_BASE_DISTANTSTARS_50_SIZE='20832'
ARCHIVE_BASE_DISTANTSTARS_50_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_DISTANTSTARS_50_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'

ARCHIVE_BASE_DISTANTSTARS_49_NAME='stellaris_distant_stars_story_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_DISTANTSTARS_49_MD5='4bb6d5c55f4c7d8bc6e6effc92625fbe'
ARCHIVE_BASE_DISTANTSTARS_49_SIZE='20832'
ARCHIVE_BASE_DISTANTSTARS_49_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_DISTANTSTARS_48_NAME='stellaris_distant_stars_story_pack_3_10_4_70670.sh'
ARCHIVE_BASE_DISTANTSTARS_48_MD5='35b7b4c4e536fdefae1668c74e3932cc'
ARCHIVE_BASE_DISTANTSTARS_48_SIZE='20832'
ARCHIVE_BASE_DISTANTSTARS_48_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_DISTANTSTARS_42_NAME='stellaris_distant_stars_story_pack_3_9_3_68314.sh'
ARCHIVE_BASE_DISTANTSTARS_42_MD5='9a03b641cc29f77008530d21e64f5232'
ARCHIVE_BASE_DISTANTSTARS_42_SIZE='21148'
ARCHIVE_BASE_DISTANTSTARS_42_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_DISTANTSTARS_39_NAME='stellaris_distant_stars_story_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_DISTANTSTARS_39_MD5='dcbb606208a16bc8f5f413239bfe69a4'
ARCHIVE_BASE_DISTANTSTARS_39_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_39_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_DISTANTSTARS_35_NAME='stellaris_distant_stars_story_pack_3_7_4_63489.sh'
ARCHIVE_BASE_DISTANTSTARS_35_MD5='d2989715cc656a73c1e2ca922bba10aa'
ARCHIVE_BASE_DISTANTSTARS_35_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_35_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_DISTANTSTARS_32_NAME='stellaris_distant_stars_story_pack_3_6_1_60754.sh'
ARCHIVE_BASE_DISTANTSTARS_32_MD5='1581145f5d4f4dbb491f3d3e1624577d'
ARCHIVE_BASE_DISTANTSTARS_32_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_32_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_DISTANTSTARS_30_NAME='stellaris_distant_stars_story_pack_3_5_3_59410.sh'
ARCHIVE_BASE_DISTANTSTARS_30_MD5='5ca6cc0d7554484af76e491211d75233'
ARCHIVE_BASE_DISTANTSTARS_30_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_30_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_DISTANTSTARS_28_NAME='stellaris_distant_stars_story_pack_3_4_5_56913.sh'
ARCHIVE_BASE_DISTANTSTARS_28_MD5='b2e6d53683346c48d44a058abd18eff9'
ARCHIVE_BASE_DISTANTSTARS_28_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_28_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_DISTANTSTARS_24_NAME='stellaris_distant_stars_story_pack_3_3_4_54421.sh'
ARCHIVE_BASE_DISTANTSTARS_24_MD5='1ca0abfacce33943685ad442ebf9d81a'
ARCHIVE_BASE_DISTANTSTARS_24_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_24_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_DISTANTSTARS_20_NAME='stellaris_distant_stars_story_pack_3_2_1_1_51520.sh'
ARCHIVE_BASE_DISTANTSTARS_20_MD5='a24264507765c470fa5d579b02fc8e32'
ARCHIVE_BASE_DISTANTSTARS_20_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_20_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_DISTANTSTARS_19_NAME='stellaris_distant_stars_story_pack_3_1_1_50008.sh'
ARCHIVE_BASE_DISTANTSTARS_19_MD5='31eeae1be998363fec20a8a09affd7b4'
ARCHIVE_BASE_DISTANTSTARS_19_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_19_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_DISTANTSTARS_18_NAME='stellaris_distant_stars_story_pack_3_0_3_47193.sh'
ARCHIVE_BASE_DISTANTSTARS_18_MD5='a19db33750977b3334a553f8c4259bf4'
ARCHIVE_BASE_DISTANTSTARS_18_SIZE='22000'
ARCHIVE_BASE_DISTANTSTARS_18_VERSION='3.0.3-gog47193'

## Ancient Relics

ARCHIVE_BASE_ANCIENTRELICS_39_NAME='stellaris_ancient_relics_3_11_2_0_71842.sh'
ARCHIVE_BASE_ANCIENTRELICS_39_MD5='47c9fe5e516406a0c7c265d532ac075c'
ARCHIVE_BASE_ANCIENTRELICS_39_SIZE='32739'
ARCHIVE_BASE_ANCIENTRELICS_39_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_ANCIENTRELICS_39_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'

ARCHIVE_BASE_ANCIENTRELICS_38_NAME='stellaris_ancient_relics_3_11_1_0_71506.sh'
ARCHIVE_BASE_ANCIENTRELICS_38_MD5='e789c87205ea9b7bf0db2a9afb1b9eef'
ARCHIVE_BASE_ANCIENTRELICS_38_SIZE='32739'
ARCHIVE_BASE_ANCIENTRELICS_38_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_ANCIENTRELICS_37_NAME='stellaris_ancient_relics_3_10_4_70670.sh'
ARCHIVE_BASE_ANCIENTRELICS_37_MD5='dacebe45d724aa535d28dc73fd2b78ab'
ARCHIVE_BASE_ANCIENTRELICS_37_SIZE='32739'
ARCHIVE_BASE_ANCIENTRELICS_37_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_ANCIENTRELICS_31_NAME='stellaris_ancient_relics_3_9_3_68314.sh'
ARCHIVE_BASE_ANCIENTRELICS_31_MD5='19909812633ca0d83ad774683f60451f'
ARCHIVE_BASE_ANCIENTRELICS_31_SIZE='33060'
ARCHIVE_BASE_ANCIENTRELICS_31_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_ANCIENTRELICS_28_NAME='stellaris_ancient_relics_3_8_4_1_65337.sh'
ARCHIVE_BASE_ANCIENTRELICS_28_MD5='491929cb272a6a866020c69a94f3e01b'
ARCHIVE_BASE_ANCIENTRELICS_28_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_28_VERSION='3.8.4.1-gog65337'

ARCHIVE_BASE_ANCIENTRELICS_24_NAME='stellaris_ancient_relics_3_7_4_63489.sh'
ARCHIVE_BASE_ANCIENTRELICS_24_MD5='51f5bc20188137581737a446b1b7498b'
ARCHIVE_BASE_ANCIENTRELICS_24_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_24_VERSION='3.7.4-gog63489'

ARCHIVE_BASE_ANCIENTRELICS_21_NAME='stellaris_ancient_relics_3_6_1_60754.sh'
ARCHIVE_BASE_ANCIENTRELICS_21_MD5='40806c04f94d933aa555bc9d9605396c'
ARCHIVE_BASE_ANCIENTRELICS_21_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_21_VERSION='3.6.1-gog60754'

ARCHIVE_BASE_ANCIENTRELICS_19_NAME='stellaris_ancient_relics_3_5_3_59410.sh'
ARCHIVE_BASE_ANCIENTRELICS_19_MD5='1052a7d2b77ba0ebbd8af19767952b47'
ARCHIVE_BASE_ANCIENTRELICS_19_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_19_VERSION='3.5.3-gog59410'

ARCHIVE_BASE_ANCIENTRELICS_17_NAME='stellaris_ancient_relics_3_4_5_56913.sh'
ARCHIVE_BASE_ANCIENTRELICS_17_MD5='b7536ac852bebe9b12a359c4c0a6ca5e'
ARCHIVE_BASE_ANCIENTRELICS_17_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_17_VERSION='3.4.5-gog56913'

ARCHIVE_BASE_ANCIENTRELICS_13_NAME='stellaris_ancient_relics_3_3_4_54421.sh'
ARCHIVE_BASE_ANCIENTRELICS_13_MD5='c09ef087df7e271758b4b8a47a1353bd'
ARCHIVE_BASE_ANCIENTRELICS_13_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_13_VERSION='3.3.4-gog54421'

ARCHIVE_BASE_ANCIENTRELICS_9_NAME='stellaris_ancient_relics_3_2_1_1_51520.sh'
ARCHIVE_BASE_ANCIENTRELICS_9_MD5='45de001d3d2b3999d6c4c8948fc22458'
ARCHIVE_BASE_ANCIENTRELICS_9_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_9_VERSION='3.2.1.1-gog51520'

ARCHIVE_BASE_ANCIENTRELICS_8_NAME='stellaris_ancient_relics_3_1_1_50008.sh'
ARCHIVE_BASE_ANCIENTRELICS_8_MD5='ec441d202f321a3d8b23af35fed33531'
ARCHIVE_BASE_ANCIENTRELICS_8_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_8_VERSION='3.1.1-gog50008'

ARCHIVE_BASE_ANCIENTRELICS_7_NAME='stellaris_ancient_relics_3_0_3_47193.sh'
ARCHIVE_BASE_ANCIENTRELICS_7_MD5='d98a169dca98257b3944517d98cd17a0'
ARCHIVE_BASE_ANCIENTRELICS_7_SIZE='34000'
ARCHIVE_BASE_ANCIENTRELICS_7_VERSION='3.0.3-gog47193'

## First Contact

ARCHIVE_BASE_FIRSTCONTACT_13_NAME='stellaris_first_contact_story_pack_3_11_2_0_71842.sh'
ARCHIVE_BASE_FIRSTCONTACT_13_MD5='24675e28ee4b230cea8fb5ed134bc6d3'
ARCHIVE_BASE_FIRSTCONTACT_13_SIZE='832'
ARCHIVE_BASE_FIRSTCONTACT_13_VERSION='3.11.2.0-gog71842'
ARCHIVE_BASE_FIRSTCONTACT_13_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'

ARCHIVE_BASE_FIRSTCONTACT_12_NAME='stellaris_first_contact_story_pack_3_11_1_0_71506.sh'
ARCHIVE_BASE_FIRSTCONTACT_12_MD5='80530039da1fef0be0aa6f6135c6b9fe'
ARCHIVE_BASE_FIRSTCONTACT_12_SIZE='832'
ARCHIVE_BASE_FIRSTCONTACT_12_VERSION='3.11.1.0-gog71506'

ARCHIVE_BASE_FIRSTCONTACT_11_NAME='stellaris_first_contact_story_pack_3_10_4_70670.sh'
ARCHIVE_BASE_FIRSTCONTACT_11_MD5='aa77a6af433d0ed023357b1af69876ce'
ARCHIVE_BASE_FIRSTCONTACT_11_SIZE='832'
ARCHIVE_BASE_FIRSTCONTACT_11_VERSION='3.10.4-gog70670'

ARCHIVE_BASE_FIRSTCONTACT_5_NAME='stellaris_first_contact_story_pack_3_9_3_68314.sh'
ARCHIVE_BASE_FIRSTCONTACT_5_MD5='870a8a53a98f020d9cb55e2b962b6172'
ARCHIVE_BASE_FIRSTCONTACT_5_SIZE='1152'
ARCHIVE_BASE_FIRSTCONTACT_5_VERSION='3.9.3-gog68314'

ARCHIVE_BASE_FIRSTCONTACT_2_NAME='stellaris_first_contact_story_pack_3_8_4_1_65337.sh'
ARCHIVE_BASE_FIRSTCONTACT_2_MD5='dd862bf0d12f5bf0a7a7c116a57f2bbb'
ARCHIVE_BASE_FIRSTCONTACT_2_SIZE='1200'
ARCHIVE_BASE_FIRSTCONTACT_2_VERSION='3.8.4.1-gog65337'


CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_MAIN_FILES='
dlc'

PKG_MAIN_DEPS="$GAME_ID"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_default

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
